# History

0.0.4 (2021-02-04)
------------------

- First official release candidate as a typer app that introduces a plugin system.


0.0.3 (2020-12-21)

- Fixed settings context if config file is not yet available.


## 0.0.1b (2020-12-18)

- First (beta) pypi release.
